dhcpkit.tests.ipv6.messages.test_confirm_message module
=======================================================

.. automodule:: dhcpkit.tests.ipv6.messages.test_confirm_message
    :members:
    :undoc-members:
    :show-inheritance:
